@@ -199,9 +199,9 @@ def recap_triangulate(config, error, nb_cams_excluded, keypoints_names, trc_path
     mean_cam_excluded = np.around(nb_cams_excluded['mean'].mean(), decimals=2)
 
     logging.info(f'--> Mean reprojection error for all points on all frames is {mean_error_px} px, which roughly corresponds to {mean_error_mm} mm. ')
-    logging.info(f'--> Cameras were excluded if likelihood was below {likelihood_threshold} and if the reprojection error was above {error_threshold_triangulation} px.')
+    logging.info(f'\nCameras were excluded if likelihood was below {likelihood_threshold} and if the reprojection error was above {error_threshold_triangulation} px.')
     logging.info(f'In average, {mean_cam_excluded} cameras had to be excluded to reach these thresholds.')
-    logging.info(f'3D coordinates are stored at {trc_path}.')
+    logging.info(f'\n3D coordinates are stored at {trc_path}.')
 
 
 def triangulation_from_best_cameras(config, coords_2D_kpt, projection_matrices):
@@ -367,7 +367,6 @@ def triangulate_all(config):
     poseTracked_folder_name = config.get('project').get('poseTracked_folder_name')
     calib_dir = os.path.join(project_dir, calib_folder_name)
     calib_file = glob.glob(calib_dir+'\*.toml')[0]
-    print(calib_file)
     poseTracked_dir = os.path.join(project_dir, poseTracked_folder_name)
     
     # Projection matrix from toml calibration file
@@ -383,19 +382,19 @@ def triangulate_all(config):
     pose_listdirs_names = next(os.walk(pose_dir))[1]
     pose_listdirs_names = natural_sort(pose_listdirs_names)
     json_dirs_names = [k for k in pose_listdirs_names if json_folder_extension in k]
-    json_files_names = [fnmatch.filter(os.listdir(os.path.join(pose_dir, js_dir)), '*.json') for js_dir in json_dirs_names]
-    json_files = [[os.path.join(pose_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
     try: 
         os.listdir(os.path.join(poseTracked_dir, json_dirs_names[0]))
+        json_files_names = [fnmatch.filter(os.listdir(os.path.join(poseTracked_dir, js_dir)), '*.json') for js_dir in json_dirs_names]
         json_tracked_files = [[os.path.join(poseTracked_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
-    except: 
-        json_tracked_files = json_files
+    except:
+        json_files_names = [fnmatch.filter(os.listdir(os.path.join(pose_dir, js_dir)), '*.json') for js_dir in json_dirs_names]
+        json_tracked_files = [[os.path.join(pose_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
     
     # Triangulation
     f_range = [[0,min([len(j) for j in json_files_names])] if frames_range==[] else frames_range][0]
 
     n_cams = len(json_dirs_names)
-    Q_tot, error_tot, nb_cams_excluded_tot = pd.DataFrame(), pd.DataFrame(), pd.DataFrame()
+    Q_tot, error_tot, nb_cams_excluded_tot = [], [], []
     for f in tqdm(range(*f_range)):
         # Get x,y,likelihood values from files
         json_tracked_files_f = [json_tracked_files[c][f] for c in range(n_cams)]
@@ -416,21 +415,20 @@ def triangulate_all(config):
             nb_cams_excluded.append(nb_cams_excluded_kpt)
 
         # Add triangulated points, errors and excluded cameras to pandas dataframes
-        Q = pd.DataFrame(np.concatenate(Q).reshape(1,-1))
-        Q_tot = Q_tot.append(Q, ignore_index=True)
-
-        error = pd.DataFrame(error).T
-        error_tot = error_tot.append(error)
-
-        nb_cams_excluded = pd.DataFrame(nb_cams_excluded).T
-        nb_cams_excluded_tot = nb_cams_excluded_tot.append(nb_cams_excluded)
-
+        Q_tot.append(np.concatenate(Q))
+        error_tot.append(error)
+        nb_cams_excluded_tot.append(nb_cams_excluded)
+    
+    Q_tot = pd.DataFrame(Q_tot)
+    error_tot = pd.DataFrame(error_tot)
+    nb_cams_excluded_tot = pd.DataFrame(nb_cams_excluded_tot)
+    
     error_tot['mean'] = error_tot.mean(axis = 1)
     nb_cams_excluded_tot['mean'] = nb_cams_excluded_tot.mean(axis = 1)
 
     # Interpolate missing values
     Q_tot = Q_tot.apply(interpolate_zeros, axis=0, args = [interpolation_kind])
-    
+   
     # Create TRC file
     trc_path = make_trc(config, Q_tot, keypoints_names, f_range)
     
